function  printConfMatrices(confusionMatrices)
% Prints the confusion matrices in a friendly mode.
% confusionMatrices: 
                   % confusionMatrices.discarded: Confusion matrix produced by objClassifier
                   % confusionMatrices.cellType: Confusion matrix produced by cellClassifier
 
%% First matrix                   
numDiscarded = confusionMatrices.discarded(1,1) + confusionMatrices.discarded(1,2);   
numTransfected = confusionMatrices.discarded(2,1) + confusionMatrices.discarded(2,2);
totalObjects = numDiscarded + numTransfected ;
accuracy = (confusionMatrices.discarded(1,1) + confusionMatrices.discarded(2,2))*100/totalObjects;
recall= confusionMatrices.discarded(2,2) / (confusionMatrices.discarded(2,1) + confusionMatrices.discarded(2,2));
precision = confusionMatrices.discarded(2,2) / (confusionMatrices.discarded(1,2) + confusionMatrices.discarded(2,2));
fprintf('\n ***   Discarded objects vs Transfected Cells\n\n\n');
fprintf('\t\t Discarded \t Transfected \t <-- Classified as\n\n');
fprintf('\t\t     %d    \t   %d        \t       Discarded: %d\n', confusionMatrices.discarded(1,1), confusionMatrices.discarded(1,2),numDiscarded);
fprintf('\t\t     %d    \t   %d        \t       Transfected: %d \n\n', confusionMatrices.discarded(2,1), confusionMatrices.discarded(2,2),numTransfected);
fprintf('\t    --------------------------------------------------------------\n\n');
fprintf('\t\t        \t          \t       Total: %d \n',totalObjects);
fprintf('\t Accuracy: %3.2f %%\n',accuracy);
fprintf('\t Precision: %3.2f \n',precision);
fprintf('\t Recall: %3.2f \n',recall);
fprintf('\n\n\n');

%% Second matrix

% If an object which should have been discarded has been classified as
% transfected cell, the size of the matrix is 3x3, but this does not happen
% always.

if (numel(confusionMatrices.cellType)~=9)
    newMatrix = zeros(3,3);
    newMatrix(2,2) = confusionMatrices.cellType(1,1);
    newMatrix(2,3) = confusionMatrices.cellType(1,2);
    newMatrix(3,2) = confusionMatrices.cellType(2,1);
    newMatrix(3,3) = confusionMatrices.cellType(2,2);    
else
    newMatrix = confusionMatrices.cellType;
end

%% Prints the matrix
numDiscarded =  newMatrix(1,1)+ newMatrix(1,2)+ newMatrix(1,3);
numDiffuse =  newMatrix(2,1)+ newMatrix(2,2)+ newMatrix(2,3);
numTranslocated = newMatrix(3,1)+ newMatrix(3,2)+ newMatrix(3,3);
totalObjects = numDiscarded+numDiffuse+numTranslocated;
accuracy = (newMatrix(1,1)+newMatrix(2,2)+newMatrix(3,3))*100/totalObjects;
precision = newMatrix(3,3)/ (newMatrix(1,3)+newMatrix(2,3)+newMatrix(3,3));
recall = newMatrix(3,3) / (newMatrix(3,1)+newMatrix(3,2)+newMatrix(3,3));
fprintf('\n ***   Diffuse vs Translocated Cells\n\n\n');
fprintf('\t\t Discarded \t Diffuse\t Translocated   <-- Classified as\n\n');
fprintf('\t\t     %d    \t   %d        \t   %d   \t\t    Discarded: %d\n', newMatrix(1,1),  newMatrix(1,2),  newMatrix(1,3), numDiscarded);
fprintf('\t\t     %d    \t   %d        \t   %d   \t\t    Diffuse: %d\n', newMatrix(2,1),  newMatrix(2,2),  newMatrix(2,3), numDiffuse);
fprintf('\t\t     %d    \t   %d        \t   %d   \t\t    Translocated: %d\n\n', newMatrix(3,1),  newMatrix(3,2),  newMatrix(3,3), numTranslocated);
fprintf('\t    -------------------------------------------------------------------------\n\n');
fprintf('\t\t        \t          \t      \t   \t    Total: %d \n',totalObjects);
fprintf('\t Accuracy: %3.2f %%\n',accuracy);
fprintf('\t Precision (Translocated): %3.2f \n',precision);
fprintf('\t Recall (Translocated): %3.2f \n',recall);
fprintf('\n\n\n');
end


