% 
% Copyright (C) 2014 Luis de la Ossa, Jesús Martínez, Sara Sáez-Atiénzar, Joaquín Jordán.
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%  
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
%


function showImages(cellLocationsByImage, cellDataByImage, imageNames)
% Shows the processed images

% cellLocationsByImage: Cell array which contains the information the information extracted from 
%                       each image in relation with the position of the cells. Each position 
%                       (which corresponds to an image) contains an array of structs (cellLocations)
%                       which correspond to a cell. Each struct has two fields:
%
%             cellLocations.BoundingBox: Coordinates of the rectangle containing the object (4x1)
%             cellLocations.Centroid: Centroid of the object.   
                        
% cellDataByImage: Cell array which contains the information extracted from each image.
%                Each position, which corresponds to a image contains an array of structs (cellData), 
%                each structure corresponds to a cell, and contains these fields:
%                 
%        cellData.numPixels: Number of pixels of the cell.
%        cellData.numPixelsOverUpperThr:  Number of pixels over params.upperBackgroundThreshold.
%        cellData.propPixelsOverUpperThr:  Proportion of pixels over params.upperBackgroundThreshold.
%        cellData.numPixelsOverAggregationThr:  Number of pixels over params.aggregationThreshold.
%        cellData.propPixelsOverAggregationThr:  Proportion of pixels over params.aggregationThreshold.         
%        cellData.majorAxisLength:  Lenght of the major axis of the ellipse containing the object.
%        cellData.minorAxisLength:  Lenght of the minor axis of the ellipse containing the object.
%        cellData.cellAvgColor:  Average color of the object
%        cellData.imgNumPixelsOverUpperThr:  Number of pixels over params.upperBackgroundThreshold in the whole image.
%        cellData.imgPropPixelsOverUpperThr: Proportion  of pixels over params.upperBackgroundThreshold in the whole image.
%        cellData.imgNumPixelsOverAggreThr:  Number of pixels over params.aggregationThreshold in the whole image.
%        cellData.imgPropPixelsOverAggreThr: Proportion  of pixels over params.aggregationThreshold in the whole image.                    
%        cellData.imgAvgColor:  Average color of the image.
%        cellData.cellPOUTvsimgPOUT:  cellData.propPixelsOverUpperThr / cellData.imgPropPixelsOverUpperThr.
%        cellData.cellPOATvsimgPOAT:  cellData.propPixelsOverAggregationThr / cellData.imgPropPixelsOverAggreThr.
%        cellData.cellColorVSImgColor:  cellData.cellAvgColor / cellData.imgAvgColor.
%        cellData.Hist:  Histogram of the object subimage.     
%        cellData.Class: Class of the cell. ([ ]=Discarded, [2] = Diffuse Aggregation, [3] = Translocated Aggregation).   
                        
                        
% imageNames: Cell array containing the names of the images.    

    numImages = size(imageNames,1);
    for indImage=1:numImages,
        imageNameCell = imageNames(indImage);
        imageName = imageNameCell{1};
        imageRGB = imread(imageName);
        imagesc(imageRGB);
        numCells = size(cellDataByImage{indImage},2);
        for indCell=1:numCells,
            boundingBox = cellLocationsByImage{indImage}(indCell).BoundingBox;
            class = cellDataByImage{indImage}(indCell).Class;
            if (class==3)
                rectangle('Position',boundingBox, 'LineWidth',2, 'EdgeColor','b');
            elseif (class==2)
                rectangle('Position',boundingBox, 'LineWidth',2, 'EdgeColor','r');
            else
                rectangle('Position',boundingBox, 'LineWidth',1, 'EdgeColor','w');
            end 
        end 
        input('Press enter to show the next image ... ')
    end 
end

