% 
% Copyright (C) 2014 Luis de la Ossa, Jesús Martínez, Sara Sáez-Atiénzar, Joaquín Jordán.
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%  
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
%

% This script allows testing the model.

% Asks the user to manually classify a set of training images and learns
% the model. Afterwards, asks the user to classify the test images and
% calculates the confusion matrices. As result, it shows these matrices and
% the results obtained by the model over the test images.

%% Fixes the parameters of the model.
setParams

%% Generates the training data.
disp('Training...');
params.askForClass = true;
[~, cellDataByImageTr, ~] = getInfoFromImages('./training/','*.jpg',params);
trainingDataset = generateDataSet(cellDataByImageTr);

%% Learns the models.
[objClassifier cellClassifier] = learnNaiveBayesModels(trainingDataset);

%% Generates the test data.
disp('Test...');
params.askForClass = true;
[cellLocationsByImageTest cellDataByImageTest imageNames] = getInfoFromImages('./test/','*.jpg', params);
testDataset = generateDataSet(cellDataByImageTest);

%% Classifies the new images and gets the confusion matrices.
[predictions confusionMatrices] = predict(testDataset, objClassifier, cellClassifier);

%% Shows the confusion matrices.
printConfMatrices(confusionMatrices);

%% Shows the results obtained by the model.
cellDataByImageTest = setClasses(cellDataByImageTest, predictions);
showImages(cellLocationsByImageTest, cellDataByImageTest, imageNames);

