% 
% Copyright (C) 2014 Luis de la Ossa, Jesús Martínez, Sara Sáez-Atiénzar, Joaquín Jordán.
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%  
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
%

% Script which allows classifiying new images.

% Asks the user to manually classify a set of training images.
% Afterwards, learns the model, and classifies a set of new images.
% Shows statistics and images if required.


%% Fixes the parameters of the model
setParams

%% Generates the training dataset
disp('Training ...');
params.askForClass = true;
[~, cellDataByImageTr, ~] = getInfoFromImages('./training/','*.jpg',params);
trainingDataset = generateDataSet(cellDataByImageTr);

%% Learns the model
[objClassifier cellClassifier] = learnNaiveBayesModels(trainingDataset);

%% Saves the classifiers for future usages
save 'models/cellClassifier.mat' cellClassifier
save 'models/objClassifier.mat' objClassifier

%% Obtains the data from the new images
disp('Processing new images...');
tic
params.askForClass = false;
[CellLocationsByImageNew CellDataByImageNew ImageNamesNew] = getInfoFromImages('./new/','*.jpg',params);
newDataset = generateDataSet(CellDataByImageNew);

%% Classifies the new cells
[predictions ~] = predict(newDataset, objClassifier, cellClassifier);

%% Shows the results
CellDataByImageNew = setClasses(CellDataByImageNew, predictions);
toc
showStats(CellDataByImageNew, ImageNamesNew);
showImages(CellLocationsByImageNew, CellDataByImageNew, ImageNamesNew);

